summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlentityattributelist.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /umbrello/umbrello/umlentityattributelist.h
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/umlentityattributelist.h')
-rw-r--r--umbrello/umbrello/umlentityattributelist.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/umlentityattributelist.h b/umbrello/umbrello/umlentityattributelist.h
index 35c0a150..774922ca 100644
--- a/umbrello/umbrello/umlentityattributelist.h
+++ b/umbrello/umbrello/umlentityattributelist.h
@@ -12,19 +12,19 @@
#ifndef UMLENTITYATTRIBUTELIST_H
#define UMLENTITYATTRIBUTELIST_H
-#include <qptrlist.h>
+#include <tqptrlist.h>
// forward declaration
class UMLEntityAttribute;
-//typedef QPtrList<UMLEntityAttribute> UMLEntityAttributeList;
-typedef QPtrListIterator<UMLEntityAttribute> UMLEntityAttributeListIt;
+//typedef TQPtrList<UMLEntityAttribute> UMLEntityAttributeList;
+typedef TQPtrListIterator<UMLEntityAttribute> UMLEntityAttributeListIt;
/**
* This sub-class adds copyInto and clone to the QPtrList<UMLEntityAttribute>
* base class.
*/
-class UMLEntityAttributeList : public QPtrList<UMLEntityAttribute>
+class UMLEntityAttributeList : public TQPtrList<UMLEntityAttribute>
{
public:
@@ -12,19 +12,19 @@
/**
- * This sub-class adds copyInto and clone to the QPtrList<UMLEntityAttribute>
+ * This sub-class adds copyInto and clone to the TQPtrList<UMLEntityAttribute>
* base class.
*/